#
# spec file for package ca-certificates-mozilla
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with trustedcerts

BuildRequires:  openssl

Name:           ca-certificates-mozilla
%define sslusrdir %{_datadir}/ca-certificates
Version:        1.76
Release:        6.1
Summary:        CA certificates for OpenSSL
License:        MPL-2.0
Group:          Productivity/Networking/Security
Url:            http://www.mozilla.org
# IMPORTANT: procedure to update certificates:
# - Check the CVS log of the cert file:
#   http://bonsai.mozilla.org/cvslog.cgi?file=mozilla/security/nss/lib/ckfw/builtins/certdata.txt&rev=HEAD
#   Alternatively hg:
#   http://hg.mozilla.org/releases/mozilla-release/file/tip/security/nss/lib/ckfw/builtins/certdata.txt
# - download the new certdata.txt
#   wget -O certdata.txt "http://mxr.mozilla.org/mozilla/source//security/nss/lib/ckfw/builtins/certdata.txt?raw=1"
# - run compareoldnew to show fingerprints of new and changed certificates
# - check the bugs referenced in cvs log and compare the checksum
#   to output of compareoldnew
# - Watch out that blacklisted or untrusted certificates are not
#   accidentally included!
Source:         certdata.txt
Source1:        extractcerts.pl
Source2:        %{name}.COPYING
Source3:        compareoldnew
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
# for update-ca-certificates
Requires(post):    ca-certificates
Requires(postun):  ca-certificates
#
Provides:       openssl-certs = 0.9.9
Obsoletes:      openssl-certs < 0.9.9

%description
This package contains some CA root certificates for OpenSSL extracted
from MozillaFirefox



%prep
%setup -qcT
/bin/cp %{SOURCE0} .
install -m 644 %{S:1} COPYING

%build
perl %{SOURCE1} --trustbits < certdata.txt

%install
mkdir -p %{buildroot}/%{sslusrdir}/mozilla
set +x
for i in *.pem; do
	args=()
	trust=`sed -n '/^# openssl-trust=/{s/^.*=//;p;q;}' "$i"`
	alias=`sed -n '/^# alias=/{s/^.*=//;p;q;}' "$i"`
%if %{with trustedcerts}
	args+=('-trustout')
	for t in $trust; do
		args+=("-addtrust" "$t")
	done
	[ -z "$alias" ] || args+=('-setalias' "$alias")
%else
	case "$trust" in
		*serverAuth*) ;;
		*) echo "skipping $i, not trusted for serverAuth"; continue ;;
	esac
%endif
	echo "$i"
	{
		grep '^#' "$i"
		openssl x509 -in "$i" "${args[@]}"
	} > "%{buildroot}/%{sslusrdir}/mozilla/$i"
done
set -x

%post
update-ca-certificates || true

%postun
update-ca-certificates || true

%files
%defattr(-, root, root)
%doc COPYING
%{sslusrdir}/mozilla

%changelog
* Thu May  3 2012 lnussel@suse.de
- update certificates to revision 1.83 (bnc#760503)
  * new: EC_ACC.pem
  * new: Hellenic_Academic_and_Research_Institutions_RootCA_2011.pem
  * new: Security_Communication_RootCA2.pem
  * removed: TC_TrustCenter_Germany_Class_2_CA.pem
  * removed: TC_TrustCenter_Germany_Class_3_CA.pem
  * removed: Verisign_Class_1_Public_Primary_Certification_Authority.1.pem
  * removed: Verisign_Class_2_Public_Primary_Certification_Authority.pem
  * removed: Verisign_Class_4_Public_Primary_Certification_Authority_G2.pem
- license change to MPL-2.0
* Fri Jan 13 2012 cfarrell@suse.com
- license update: MPL-1.1 or GPL-2.0+ or LGPL-2.1+
  SPDX format and correct GPL and LGPL tags to include or later
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Wed Aug 31 2011 lnussel@suse.de
- update certificates to revision 1.76
  * new: Go_Daddy_Root_Certificate_Authority_G2.pem
  * new: Starfield_Root_Certificate_Authority_G2.pem
  * new: Starfield_Services_Root_Certificate_Authority_G2.pem
  * new: AffirmTrust_Commercial.pem
  * new: AffirmTrust_Networking.pem
  * new: AffirmTrust_Premium.pem
  * new: AffirmTrust_Premium_ECC.pem
  * new: Certum_Trusted_Network_CA.pem
  * new: Certinomis_Autorit_Racine.pem
  * new: Root_CA_Generalitat_Valenciana.pem
  * new: A_Trust_nQual_03.pem
  * new: TWCA_Root_Certification_Authority.pem
  * removed: DigiNotar_Root_CA.pem (bnc#714931)
* Mon Jan 31 2011 lnussel@suse.de
- update certificates to revision 1.70
  * new: AddTrust_Qualified_Certificates_Root.pem
  * new: Autoridad_de_Certificacion_Firmaprofesional_CIF_A62634068.pem
  * new: Chambers_of_Commerce_Root_2008.pem
  * new: Global_Chambersign_Root_2008.pem
  * new: Izenpe_com.pem
  * new: TC_TrustCenter_Universal_CA_III.pem
* Mon Sep 27 2010 lnussel@suse.de
- update certificates to revision 1.65
  * new: E_Guven_Kok_Elektronik_Sertifika_Hizmet_Saglayicisi.pem
  * new: GlobalSign_Root_CA_R3.pem
  * new: Microsec_e_Szigno_Root_CA_2009.pem
  * new: Verisign_Class_1_Public_Primary_Certification_Authority.1.pem
  * new: Verisign_Class_3_Public_Primary_Certification_Authority.1.pem
* Fri May 21 2010 lnussel@suse.de
- update certificates to revision 1.64
  * removed "RSA Security 1024 V3" certificate
* Thu Apr  8 2010 lnussel@suse.de
- require ca-certificates also for postun
* Thu Apr  1 2010 lnussel@suse.de
- don't output trusted certs by default as it's not supported by
  gnutls yet and pidgin scans /etc/ssl/certs
* Thu Apr  1 2010 lnussel@suse.de
- update certificates to revision 1.62
* Fri Mar 26 2010 lnussel@suse.de
- extract trustbits as comment as Fedora does
- convert to trusted certificates in spec file instead
* Thu Mar 25 2010 lnussel@suse.de
- rename to ca-certificates-mozilla
- output trusted certificates
- use utf8 in file names
* Tue Feb  2 2010 lnussel@suse.de
- update certificates to revision 1.57
- add script to compare with previous certificates
* Wed Sep 30 2009 lnussel@suse.de
- update certifiates to cvs revision 1.56
- exclude certficates that are not trusted for identifying web sites
* Tue Dec  2 2008 cfarrell@suse.de
- Add openssl-certs.COPYING to fix bnc#441356
* Thu Oct  9 2008 lnussel@suse.de
- use certificates from MozillaFirefox
* Wed Jul  9 2008 mkoenig@suse.de
- split out the CA root certificates from the openssl certs
  subpackage into a package of its own.
